#!/usr/bin/env sh
# SPDX-License-Identifier: AGPL-3.0-or-later
# SPDX-FileCopyrightText: 2021-2024 JayVii <jayvii[AT]posteo[DOT]de>

# $1 - HTML Root
# $2 - prv/pub
# $3 - repo name
# $4 - description
# $5 - owner/maintainer

# Error out if not all options are given
if [ -z "$5" ]; then
    echo "Usage:
git_create_repo.sh \\
    \"/var/www/git.example.git\" \\
    \"pub\" \\
    \"stagit-jayvii.de\" \\
    \"An example repository.\" \\
    \"JayVii\"
    "
    exit 1;
fi

# If Git Repositories / folders already exist, exit immediately
if [ -d "${1}/${2}/${3}.git" ]; then
    echo "${2}/${3} already exists!"
    exit 1;
fi

# Retrieve URL if set
if [ -f "${1}/url" ]; then
    URL=`cat ${1}/url`
else
    URL=""
fi

# Create Folders
mkdir -p "${1}/${2}/${3}/"
mkdir -p "${1}/${2}/${3}/exports/"
mkdir -p "${1}/${2}/${3}.git/"

# Ensure that export-directory is browsable
echo "Options +Indexes" > "${1}/${2}/${3}/exports/.htaccess"

# Git-Repository
cd "${1}/${2}/${3}.git" || exit 1;

# create bare branch
git init --bare || exit 1;

# Set default branch to "main"
echo "ref: refs/heads/main" > HEAD

# Add description
echo "$4" > description

# Add owner
echo "$5" > owner

# Add Clone URL, if "url" file exists in root directory
if [ -f "${1}/url" ]; then
    URL=`cat ${1}/url`
    echo "${URL}/${2}/${3}.git" > "${1}/${2}/${3}.git/url"
fi

# Add Hooks
PUH_FILE="${1}/${2}/${3}.git/hooks/post-update"
touch "$PUH_FILE"
chmod +x "$PUH_FILE"
echo "#!/usr/bin/env sh
~/bin/git_post_push.sh \"${1}\" \"${2}\" \"${3}\" \"\$@\"" >> "$PUH_FILE"

# make branch cloneable via http(s)
git update-server-info

# enforce file permissions
chmod 770 -R "${1}/${2}/${3}"
chmod 770 -R "${1}/${2}/${3}.git"

# User output
echo "The repository is available via git clone ${URL}/${2}/${3}.git"
